@@ -7,7 +7,8 @@ use Log::Any '$log';
 
 use Data::Clone;
 use DateTime;
-use Perinci::Sub::Gen::AccessTable qw(gen_read_table_func);
+use Perinci::Sub::Gen::AccessTable 0.16 qw(gen_read_table_func);
+use Perinci::Sub::Util qw(wrapres);
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -17,10 +18,9 @@ our @EXPORT_OK = qw(
                        count_id_workdays
                );
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 our %SPEC;
-
 my @fixed_holidays = (
     my $newyear = {
         day        =>  1, month =>  1,
@@ -452,7 +452,7 @@ $year_holidays{2011} = [
 
 # decreed may 16, 2011
 my $eidulf2012;
-$year_holidays{2012} = _make_jl_tentative [
+$year_holidays{2012} = [
     _h_chnewyear ({_expand_dm("23-01")}, {hyear=>2563}),
     _h_mawlid    ({_expand_dm("04-02")}),
     _h_nyepi     ({_expand_dm("23-03")}, {hyear=>1934}),
@@ -471,6 +471,31 @@ $year_holidays{2012} = _make_jl_tentative [
     _jointlv     ({_expand_dm("26-12")}, {holiday=>$christmas}),
 ];
 
+# decreed jul 19, 2012
+my $eidulf2013;
+my $eidula2013;
+$year_holidays{2013} = [
+    _h_mawlid    ({_expand_dm("24-01")}),
+    _h_chnewyear ({_expand_dm("10-02")}, {hyear=>2564}),
+    _h_nyepi     ({_expand_dm("12-03")}, {hyear=>1935}),
+    _h_goodfri   ({_expand_dm("29-03")}),
+    _h_ascension ({_expand_dm("09-05")}),
+    _h_vesakha   ({_expand_dm("25-05")}, {hyear=>2557}),
+    _h_isramiraj ({_expand_dm("06-06")}),
+    ($eidulf2013 =
+    _h_eidulf    ({_expand_dm("08-08")}, {hyear=>1434, day=>1})),
+    _h_eidulf    ({_expand_dm("09-08")}, {hyear=>1434, day=>2}),
+    ($eidula2013 =
+    _h_eidula    ({_expand_dm("15-10")})),
+    _h_hijra     ({_expand_dm("05-11")}, {hyear=>1435}),
+
+    _jointlv     ({_expand_dm("05-08")}, {holiday=>$eidulf2013}),
+    _jointlv     ({_expand_dm("06-08")}, {holiday=>$eidulf2013}),
+    _jointlv     ({_expand_dm("07-08")}, {holiday=>$eidulf2013}),
+    _jointlv     ({_expand_dm("14-10")}, {holiday=>$eidula2013}),
+    _jointlv     ({_expand_dm("26-12")}, {holiday=>$christmas}),
+];
+
 my @years     = sort keys %year_holidays;
 our $min_year = $years[0];
 our $max_year = $years[-1];
@@ -514,9 +539,10 @@ for my $year ($min_year .. $max_year) {
 }
 
 my $res = gen_read_table_func(
+    name => 'list_id_holidays',
     table_data => \@holidays,
     table_spec => {
-        columns => {
+        fields => {
             date => {
                 schema => 'str*',
                 index => 0,
@@ -585,6 +611,7 @@ my $res = gen_read_table_func(
         },
         pk => 'date',
     },
+    langs => ['en_US', 'id_ID'],
 );
 
 die "BUG: Can't generate func: $res->[0] - $res->[1]"
@@ -603,10 +630,6 @@ List holidays and joint leave days ("cuti bersama").
 $AVAILABLE_YEARS
 
 _
-$SPEC{list_id_holidays} = $meta;
-no warnings;
-*list_id_holidays = $res->[2]{code};
-use warnings;
 
 sub _check_date_arg {
     my ($date) = @_;
@@ -687,7 +710,7 @@ sub enum_id_workdays {
     push @args, "year.max"=>$end_date->year;
     push @args, (is_holiday=>1) if !$observe_joint_leaves;
     my $res = list_id_holidays(@args);
-    return [500, "Can't list holidays: $res->[0] - $res->[1]"]
+    return wrapres([500, "Can't list holidays: "], $res)
         unless $res->[0] == 200;
     #use Data::Dump; dd $res;
 
@@ -729,7 +752,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-version 0.08
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -827,26 +850,33 @@ year.
 
 This API will also be available on GudangAPI, http://gudangapi.com/
 
+=head1 DESCRIPTION
+
+
+This module has L<Rinci> metadata.
+
 =head1 FUNCTIONS
 
 
+None are exported by default, but they are exportable.
+
 =head2 count_id_workdays(%args) -> [status, msg, result, meta]
 
 Count working days for a certain period.
 
-Working day is defined as day that is not SaturdayB</Sunday/holiday/joint leave
-days>. If workB<saturdays is set to true, Saturdays are also counted as working
+Working day is defined as day that is not SaturdayI</Sunday/holiday/joint leave
+days>. If workI<saturdays is set to true, Saturdays are also counted as working
 days. If observe>joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2012 (joint leave days until
-2012).
+Contains data from years 2002 to 2013 (joint leave days until
+2013).
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<end_date>* => I<str>
+=item * B<end_date> => I<str>
 
 End date.
 
@@ -857,7 +887,7 @@ or a DateTime object, is accepted.
 
 If set to 0, do not observe joint leave as holidays.
 
-=item * B<start_date>* => I<str>
+=item * B<start_date> => I<str>
 
 Starting date.
 
@@ -878,19 +908,19 @@ Returns an enveloped result (an array). First element (status) is an integer con
 
 Enumerate working days for a certain period.
 
-Working day is defined as day that is not SaturdayB</Sunday/holiday/joint leave
-days>. If workB<saturdays is set to true, Saturdays are also counted as working
+Working day is defined as day that is not SaturdayI</Sunday/holiday/joint leave
+days>. If workI<saturdays is set to true, Saturdays are also counted as working
 days. If observe>joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2012 (joint leave days until
-2012).
+Contains data from years 2002 to 2013 (joint leave days until
+2013).
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<end_date>* => I<str>
+=item * B<end_date> => I<str>
 
 End date.
 
@@ -901,7 +931,7 @@ or a DateTime object, is accepted.
 
 If set to 0, do not observe joint leave as holidays.
 
-=item * B<start_date>* => I<str>
+=item * B<start_date> => I<str>
 
 Starting date.
 
@@ -924,14 +954,14 @@ List Indonesian holidays in calendar.
 
 List holidays and joint leave days ("cuti bersama").
 
-Contains data from years 2002 to 2012 (joint leave days until
-2012).
+Contains data from years 2002 to 2013 (joint leave days until
+2013).
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<date>* => I<str>
+=item * B<date> => I<str>
 
 Only return records where the 'date' field equals specified value.
 
@@ -939,7 +969,7 @@ Only return records where the 'date' field equals specified value.
 
 Only return records where the 'date' field contains specified text.
 
-=item * B<date.is>* => I<str>
+=item * B<date.is> => I<str>
 
 Only return records where the 'date' field equals specified value.
 
@@ -963,11 +993,11 @@ Only return records where the 'date' field is less than specified value.
 
 Only return records where the 'date' field is greater than specified value.
 
-=item * B<day>* => I<int>
+=item * B<day> => I<int>
 
 Only return records where the 'day' field equals specified value.
 
-=item * B<day.is>* => I<int>
+=item * B<day.is> => I<int>
 
 Only return records where the 'day' field equals specified value.
 
@@ -993,11 +1023,11 @@ Return array of full records instead of just ID fields.
 
 By default, only the key (ID) field is returned per result entry.
 
-=item * B<dow>* => I<int>
+=item * B<dow> => I<int>
 
 Only return records where the 'dow' field equals specified value.
 
-=item * B<dow.is>* => I<int>
+=item * B<dow.is> => I<int>
 
 Only return records where the 'dow' field equals specified value.
 
@@ -1017,31 +1047,31 @@ Only return records where the 'dow' field is less than specified value.
 
 Only return records where the 'dow' field is greater than specified value.
 
-=item * B<fields>* => I<array>
+=item * B<fields> => I<array>
 
 Select fields to return.
 
-=item * B<is_holiday>* => I<bool>
+=item * B<is_holiday> => I<bool>
 
 Only return records where the 'is_holiday' field equals specified value.
 
-=item * B<is_holiday.is>* => I<bool>
+=item * B<is_holiday.is> => I<bool>
 
 Only return records where the 'is_holiday' field equals specified value.
 
-=item * B<is_joint_leave>* => I<bool>
+=item * B<is_joint_leave> => I<bool>
 
 Only return records where the 'is_joint_leave' field equals specified value.
 
-=item * B<is_joint_leave.is>* => I<bool>
+=item * B<is_joint_leave.is> => I<bool>
 
 Only return records where the 'is_joint_leave' field equals specified value.
 
-=item * B<month>* => I<int>
+=item * B<month> => I<int>
 
 Only return records where the 'month' field equals specified value.
 
-=item * B<month.is>* => I<int>
+=item * B<month.is> => I<int>
 
 Only return records where the 'month' field equals specified value.
 
@@ -1061,7 +1091,7 @@ Only return records where the 'month' field is less than specified value.
 
 Only return records where the 'month' field is greater than specified value.
 
-=item * B<q> => I<str> (default: 1)
+=item * B<q> => I<str>
 
 Search.
 
@@ -1084,7 +1114,7 @@ Order records according to certain field(s).
 A list of field names separated by comma. Each field can be prefixed with '-' to
 specify descending order instead of the default ascending.
 
-=item * B<tags>* => I<array>
+=item * B<tags> => I<array>
 
 Only return records where the 'tags' field equals specified value.
 
@@ -1092,7 +1122,7 @@ Only return records where the 'tags' field equals specified value.
 
 Only return records where the 'tags' field is an array/list which contains specified value.
 
-=item * B<tags.is>* => I<array>
+=item * B<tags.is> => I<array>
 
 Only return records where the 'tags' field equals specified value.
 
@@ -1108,11 +1138,11 @@ When enabled, function will return each record as hash/associative array
 (field name => value pairs). Otherwise, function will return each record
 as list/array (field value, field value, ...).
 
-=item * B<year>* => I<int>
+=item * B<year> => I<int>
 
 Only return records where the 'year' field equals specified value.
 
-=item * B<year.is>* => I<int>
+=item * B<year.is> => I<int>
 
 Only return records where the 'year' field equals specified value.
 
